import { NativeModules, Platform } from 'react-native'
import { _APP_SETTINGS, ez, user, lang } from './';

const { InAppUtils } = NativeModules;

export const iapIOS = {

  products: _APP_SETTINGS.in_app_purchases,

  init: () => {

    let identifiers = [];    
    
    iapIOS.products.map(p => identifiers.push(p.product_id));
    InAppUtils.loadProducts(identifiers, (error, prods) => {
      console.warn("purchase error", error, "\nproducts", prods);
      for(let p of prods) {
        p.product_id = p.identifier;
        iapIOS.products.map(r => {
          if(r.product_id === p.product_id) {
            r.price = ez.moneyFormat(p.price);
            r.currency = p.currenctSymbol || p.currencyCode || r.currency;
          }
        });
      }

      InAppUtils.receiptData((error, receiptData) => {
        if(error) {
          user.update({ is_premium: 0, is_promoted_account: 0 })
          .then(res => {})
          .catch(err => {});
        }
        else {          
          user.purchaseVerifyIOS(receiptData, "")
          .then(res => {})
          .catch(err => {});
        }
      });

    });
  },

  purchase: (productId:string, showAlert?:boolean=true) => {
    return new Promise((resolve, reject) => {
      InAppUtils.canMakePayments((enabled) => {
        if(enabled) {
          InAppUtils.purchaseProduct(productId, (error, response) => {

            if(error) {
              reject(error);
              if(showAlert) {
                ez.alert(lang("error"), lang("purchaseFail"))
              }
              return;
            }

            if(response && response.productIdentifier) {
              user.purchaseVerifyIOS(response.transactionReceipt, "")
              .then(res => {
                if(res.error === 0) {
                  resolve();
                  if(showAlert) {
                    ez.alert(lang("success"), lang("purchaseSuccess"))
                  }
                }
                else {
                  reject("purchase verify failed");
                  if(showAlert) {
                    ez.alert(lang("error"), lang("purchaseFail"))
                  }
                }
              })
              .catch(err => {
                reject(err);
                if(showAlert) {
                  ez.alert(lang("error"), lang("purchaseFail"))
                }
              })
            }

          });
        }
        else {
          reject("purchasingDisabledOnDevice");
          if(showAlert) {
            ez.alert(lang("error"), lang("purchasingDisabledOnDevice"))
          }
        }
      })
    })
  },

  restorePurchases: (showAlert?:boolean=true) => {
    return new Promise((resolve, reject) => {
      InAppUtils.restorePurchases((error, response) => {
        if(!error) {
          if(response.length === 0) {
            // aldığı bir şey yok
          }
          else {
            response.forEach((purchase) => {
              user.purchaseVerifyIOS(purchase.transactionReceipt, purchase.transactionIdentifier)
              .then(res => {})
              .catch(err => {})
            })
          }
        }
        if(showAlert) {
          ez.alert(lang("success"), lang("purchasesRestored"))
        }
        resolve();
      })  
    })
    
  },

}
  
export const iapAndroid = {

}